@@ -801,7 +801,7 @@ pdgstrf(superlu_dist_options_t * options, int m, int n, double anorm,
 #endif
 
 #ifdef GPU_ACC /*-- use GPU --*/
-    int superlu_acc_offload = sp_ienv_dist(10, options); //get_acc_offload();
+    int superlu_acc_offload = get_acc_offload(options);
 
     int gpublas_nb = get_gpublas_nb(); // default 64
     int nstreams = get_num_gpu_streams (); // default 8
